/**
 * \mainpage 10 komplex szám abszolút értéke
 *
 * \section feladat Feladat
 * Olvassunk be pontosan 10 komplex számot, majd
 * írjuk ki a számokat és abszolút értéküket fordított sorrendben!
 *
 * \section megv Megvalósítás
 * Megvalósítás: objektum-orientált dekompozícióval
 * operetor overload használata nélkül.
 *
 * \section korl Korlátozás, hiányosságok
 * Nincs indexhatár ellenőrzés.
 * Csak a használt metódusokat valósítottuk meg.
 *
 */

#include <iostream>
#include <math.h>

using std::cin;
using std::cout;
using std::endl;

/**
 * Komplex osztály
 * Komplex viselkedést megvalósító osztály.
 * Most csak a feladat megvalósításához szükséges műveleteket definiáljuk
 */
class Komplex {
	double re;		// valós rész
	double im;		// képzetes rész
public:
    void beolvas()   { cin >> re >> im; }               ///< Komplex beolvas
    void kiir()      { cout << re << ' ' << im; }       ///< Komplex kiírás
    double abs()     { return sqrt(re*re + im*im); }    ///< abszolút érték
};

/**
 * KomplexTar osztály
 * Tároló ami max 10 komplex számot tud tárolni
 * Az egyszer?ség kedvéért nincs indexhatár ellen?rzés !
 */
class KomplexTar {
    Komplex t[10];      // bels? objektumtömböt tartalmaz a tároláshoz
public:
    void tarol(const int i, const Komplex& k) { t[i] = k; } ///< Betesz a tárba
    Komplex elovesz(const int i) { return t[i]; }           ///< Kivesz a tárból
};


/**
 * Főprogram.
 */
int main()
{
    KomplexTar t;       // tároló létrehozása
    int i;              // nem a for-ban van, hogy visual C++ 6.0 -ban is jo legyen

    for (i = 0; i < 10; i++) {
        Komplex k;      // komplex létrehozása
        k.beolvas();    // beolvas a megfelel? formátumban
        t.tarol(i, k);  // tárol
    }

    for (i = 9; i >= 0; i--) {
        Komplex k = t.elovesz(i); // definíció és inic.
        k.kiir();       // kiir a megfelel? formátumban
        cout << ' ' << k.abs() << endl; // abszolút értéket is
    }
    return 0;
}
